@@ -6,10 +6,13 @@
 "use strict";
 
 const forEachBail = require("./forEachBail");
+const { PathType, getType } = require("./util/path");
 
 /** @typedef {import("./Resolver")} Resolver */
+/** @typedef {import("./Resolver").ResolveRequest} ResolveRequest */
 /** @typedef {import("./Resolver").ResolveStepHook} ResolveStepHook */
-/** @typedef {{alias: string|Array<string>|false, name: string, onlyModule?: boolean}} AliasOption */
+/** @typedef {string | Array<string> | false} Alias */
+/** @typedef {{alias: Alias, name: string, onlyModule?: boolean}} AliasOption */
 
 module.exports = class AliasPlugin {
 	/**
@@ -29,6 +32,27 @@ module.exports = class AliasPlugin {
 	 */
 	apply(resolver) {
 		const target = resolver.ensureHook(this.target);
+		/**
+		 * @param {string} maybeAbsolutePath path
+		 * @returns {null|string} absolute path with slash ending
+		 */
+		const getAbsolutePathWithSlashEnding = maybeAbsolutePath => {
+			const type = getType(maybeAbsolutePath);
+			if (type === PathType.AbsolutePosix || type === PathType.AbsoluteWin) {
+				return resolver.join(maybeAbsolutePath, "_").slice(0, -1);
+			}
+			return null;
+		};
+		/**
+		 * @param {string} path path
+		 * @param {string} maybeSubPath sub path
+		 * @returns {boolean} true, if path is sub path
+		 */
+		const isSubPath = (path, maybeSubPath) => {
+			const absolutePath = getAbsolutePathWithSlashEnding(maybeSubPath);
+			if (!absolutePath) return false;
+			return path.startsWith(absolutePath);
+		};
 		resolver
 			.getHook(this.source)
 			.tapAsync("AliasPlugin", (request, resolveContext, callback) => {
@@ -37,18 +61,33 @@ module.exports = class AliasPlugin {
 				forEachBail(
 					this.options,
 					(item, callback) => {
+						/** @type {boolean} */
 						let shouldStop = false;
 						if (
 							innerRequest === item.name ||
-							(!item.onlyModule && innerRequest.startsWith(item.name + "/"))
+							(!item.onlyModule &&
+								(request.request
+									? innerRequest.startsWith(`${item.name}/`)
+									: isSubPath(innerRequest, item.name)))
 						) {
-							const remainingRequest = innerRequest.substr(item.name.length);
+							/** @type {string} */
+							const remainingRequest = innerRequest.slice(item.name.length);
+							/**
+							 * @param {Alias} alias alias
+							 * @param {(err?: null|Error, result?: null|ResolveRequest) => void} callback callback
+							 * @returns {void}
+							 */
 							const resolveWithAlias = (alias, callback) => {
 								if (alias === false) {
+									/** @type {ResolveRequest} */
 									const ignoreObj = {
 										...request,
 										path: false
 									};
+									if (typeof resolveContext.yield === "function") {
+										resolveContext.yield(ignoreObj);
+										return callback(null, null);
+									}
 									return callback(null, ignoreObj);
 								}
 								if (
@@ -57,6 +96,7 @@ module.exports = class AliasPlugin {
 								) {
 									shouldStop = true;
 									const newRequestStr = alias + remainingRequest;
+									/** @type {ResolveRequest} */
 									const obj = {
 										...request,
 										request: newRequestStr,
@@ -82,6 +122,11 @@ module.exports = class AliasPlugin {
 								}
 								return callback();
 							};
+							/**
+							 * @param {null|Error} [err] error
+							 * @param {null|ResolveRequest} [result] result
+							 * @returns {void}
+							 */
 							const stoppingCallback = (err, result) => {
 								if (err) return callback(err);
 
